package meta

import (
    "net/http"
    "encoding/xml"
)

// Very reduced item, as only title, link and pubDate are useful for a version check.
type Item struct {
    Title     string    `xml:"title"`
    Link      string    `xml:"link"`
    PubDate   string    `xml:"pubDate"`
}

type Channel struct {
    Items []Item `xml:"item"`
}

type Rss struct {
    Channel Channel `xml:"channel"`
}

// Checks if the current version is up to date or not. If there is a newer / different
// version.
func CheckVersionIsUpToDate() (Item, error) {

    resp, err := http.Get("https://gitea.armuli.eu/museum-digital/museum-digital-webdav-uploader/releases.rss")
    if err != nil {
        return Item{}, err
    }
    defer resp.Body.Close()

    rss := Rss{}

    decoder := xml.NewDecoder(resp.Body)
    decodeErr := decoder.Decode(&rss)
    if decodeErr != nil {
        return Item{}, err
    }

    newestItem := rss.Channel.Items[0];
    if (newestItem.Title == GetVersion() || newestItem.Title == "v" + GetVersion()) {
        return Item{}, nil
    }
    return newestItem, nil

}
